@@ -1,6 +1,6 @@
 try:
     from .version import __version__
-    from . import ngshare, vngshare
+    from . import ngshare
 except ImportError:  # pragma: no cover
     from version import __version__
-    import ngshare, vngshare
+    import ngshare
